@@ -8,4 +8,4 @@ AUTORELOAD_FILETYPES = DEBUG_TOOLBAR_CONFIG.get(
     'AUTORELOAD_FILETYPES',
     ('template', 'css', 'js'))
 
-AUTORELOAD_TIMEOUT = DEBUG_TOOLBAR_CONFIG.get('AUTORELOAD_TIMEOUT', 15)
+AUTORELOAD_TIMEOUT = DEBUG_TOOLBAR_CONFIG.get('AUTORELOAD_TIMEOUT', None)
